@@ -228,14 +228,13 @@ struct _GnomeCanvasItemClass {
 };
 
 
-/* Standard Gtk function */
-GtkType gnome_canvas_item_get_type (void) G_GNUC_CONST;
+GType gnome_canvas_item_get_type (void) G_GNUC_CONST;
 
 /* Create a canvas item using the standard Gtk argument mechanism.  The item is
  * automatically inserted at the top of the specified canvas group.  The last
  * argument must be a NULL pointer.
  */
-GnomeCanvasItem *gnome_canvas_item_new (GnomeCanvasGroup *parent, GtkType type,
+GnomeCanvasItem *gnome_canvas_item_new (GnomeCanvasGroup *parent, GType type,
 					const gchar *first_arg_name, ...);
 
 /* Constructors for use in derived classes and language wrappers */
@@ -386,8 +385,7 @@ struct _GnomeCanvasGroupClass {
 };
 
 
-/* Standard Gtk function */
-GtkType gnome_canvas_group_get_type (void) G_GNUC_CONST;
+GType gnome_canvas_group_get_type (void) G_GNUC_CONST;
 
 
 /*** GnomeCanvas ***/
@@ -462,6 +460,11 @@ struct _GnomeCanvas {
 	/* Tolerance distance for picking items */
 	int close_enough;
 
+	/* Whether the canvas should center the scroll region in the middle of
+	 * the window if the scroll region is smaller than the window.
+	 */
+	unsigned int center_scroll_region : 1;
+
 	/* Whether items need update at next idle loop iteration */
 	unsigned int need_update : 1;
 
@@ -507,8 +510,7 @@ struct _GnomeCanvasClass {
 };
 
 
-/* Standard Gtk function */
-GtkType gnome_canvas_get_type (void) G_GNUC_CONST;
+GType gnome_canvas_get_type (void) G_GNUC_CONST;
 
 /* Creates a new canvas.  You should check that the canvas is created with the
  * proper visual and colormap.  Any visual will do unless you intend to insert
@@ -537,6 +539,12 @@ void gnome_canvas_set_scroll_region (GnomeCanvas *canvas,
 void gnome_canvas_get_scroll_region (GnomeCanvas *canvas,
 				     double *x1, double *y1, double *x2, double *y2);
 
+/* Whether the canvas centers the scroll region if it is smaller than the window */
+void gnome_canvas_set_center_scroll_region (GnomeCanvas *canvas, gboolean center_scroll_region);
+
+/* Returns whether the canvas is set to center the scroll region if it is smaller than the window */
+gboolean gnome_canvas_get_center_scroll_region (GnomeCanvas *canvas);
+
 /* Sets the number of pixels that correspond to one unit in world coordinates */
 void gnome_canvas_set_pixels_per_unit (GnomeCanvas *canvas, double n);
 
